@@ -299,7 +299,7 @@ static int cfb64_test();
 static int ede_cfb64_test();
 #endif
 
-int
+void
 test_main(void)
 	{
 	int i,j,err=0;
@@ -358,7 +358,7 @@ test_main(void)
 			printf("Key error %2d:%d\n",i+2,j);
 			err=1;
 			}
-		if ((j=des_key_sched(&key_data[i+2],ks3)) != 0)
+		if (i+2 < NUM_TESTS && (j=des_key_sched(&key_data[i+2],ks3)) != 0)
 			{
 			printf("Key error %2d:%d\n",i+3,j);
 			err=1;
@@ -741,18 +741,16 @@ plain[8+4], plain[8+5], plain[8+6], plain[8+7]);
 		}
 	printf("\n");
 #endif
-	exit(err);
-	return(0);
+	ASSERT (err == 0);
 	}
 
-static char *pt(p)
-const unsigned char *p;
+static char *pt(const unsigned char *p)
 	{
 	static char bufs[10][20];
 	static int bnum=0;
 	char *ret;
 	int i;
-	static char *f="0123456789ABCDEF";
+	static const char *f="0123456789ABCDEF";
 
 	ret= &(bufs[bnum++][0]);
 	bnum%=10;
